==> peony-extensions_3.0.1.orig.tar.gz: peony-extensions/peony-extension-computer-view/peony-extension-computer-view_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr" sourcelanguage="en_GB">
<context>
    <name>ComputerItemDelegate</name>
    <message>
        <location filename="computer-view/computer-item-delegate.cpp" line="146"/>
        <source>You should mount volume first</source>
        <translation>Önce bölümü bağlamalısınız</translation>
    </message>
</context>
<context>
    <name>ComputerNetworkItem</name>
    <message>
        <location filename="computer-view/computer-network-item.cpp" line="45"/>
        <source>Network Neighborhood</source>
        <translation>Ağ Komşuları</translation>
    </message>
</context>
<context>
    <name>ComputerRemoteVolumeItem</name>
    <message>
        <location filename="computer-view/computer-remote-volume-item.cpp" line="47"/>
        <source>Remote</source>
        <translation>Uzak</translation>
    </message>
</context>
<context>
    <name>ComputerVolumeItem</name>
    <message>
        <location filename="computer-view/computer-volume-item.cpp" line="33"/>
        <source>Volume</source>
        <translation>Bölüm</translation>
    </message>
    <message>
        <location filename="computer-view/computer-volume-item.cpp" line="41"/>
        <source>File System</source>
        <translation>Dosya Sistemi</translation>
    </message>
</context>
<context>
    <name>LoginRemoteFilesystem</name>
    <message>
        <location filename="login-remote-filesystem.ui" line="41"/>
        <source>Connect to Sever</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="89"/>
        <source>server information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="111"/>
        <source>user information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="141"/>
        <source>tag</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="196"/>
        <source>user</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="252"/>
        <source>password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="308"/>
        <source>protocol</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="351"/>
        <source>server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="382"/>
        <source>directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="411"/>
        <source>SAMBA</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="416"/>
        <source>FTP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="445"/>
        <source>/</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="476"/>
        <source>port</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="508"/>
        <source>20</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="513"/>
        <source>21</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="518"/>
        <source>137</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="523"/>
        <source>138</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="528"/>
        <source>139</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="533"/>
        <source>445</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="592"/>
        <source>ok</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="623"/>
        <source>cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Peony::ComputerViewContainer</name>
    <message>
        <location filename="computer-view-container.cpp" line="85"/>
        <source>Connect a server</source>
        <translation>Servere bağlan</translation>
    </message>
    <message>
        <location filename="computer-view-container.cpp" line="112"/>
        <source>sftp://, etc...</source>
        <translation>sftp://, gibi...</translation>
    </message>
    <message>
        <location filename="computer-view-container.cpp" line="113"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="computer-view-container.cpp" line="114"/>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="computer-view-container.cpp" line="124"/>
        <source>Unmount</source>
        <translation>Bağlantıyı kes</translation>
    </message>
    <message>
        <location filename="computer-view-container.cpp" line="130"/>
        <location filename="computer-view-container.cpp" line="145"/>
        <source>Property</source>
        <translation>Özellik</translation>
    </message>
    <message>
        <location filename="computer-view-container.cpp" line="132"/>
        <source>You have to mount this volume first</source>
        <translation>Önce bu bölümü bağlamalısınız</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="peony-computer-view-plugin.h" line="42"/>
        <source>Computer View</source>
        <translation>Bilgisayar Görünümü</translation>
    </message>
    <message>
        <location filename="peony-computer-view-plugin.h" line="43"/>
        <source>Show drives, network and personal directories.</source>
        <translation>Sürücüleri, ağı ve kişisel dizinleri göster.</translation>
    </message>
</context>
</TS>

==> peony-extensions_3.0.2.orig.tar.gz: peony-extensions/peony-extension-computer-view/peony-extension-computer-view_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr" sourcelanguage="en_GB">
<context>
    <name>ComputerItemDelegate</name>
    <message>
        <location filename="computer-view/computer-item-delegate.cpp" line="146"/>
        <source>You should mount volume first</source>
        <translation>Önce bölümü bağlamalısınız</translation>
    </message>
</context>
<context>
    <name>ComputerNetworkItem</name>
    <message>
        <location filename="computer-view/computer-network-item.cpp" line="45"/>
        <source>Network Neighborhood</source>
        <translation>Ağ Komşuları</translation>
    </message>
</context>
<context>
    <name>ComputerRemoteVolumeItem</name>
    <message>
        <location filename="computer-view/computer-remote-volume-item.cpp" line="54"/>
        <source>Remote</source>
        <translation>Uzak</translation>
    </message>
</context>
<context>
    <name>ComputerVolumeItem</name>
    <message>
        <location filename="computer-view/computer-volume-item.cpp" line="34"/>
        <source>Volume</source>
        <translation>Bölüm</translation>
    </message>
    <message>
        <location filename="computer-view/computer-volume-item.cpp" line="42"/>
        <source>File System</source>
        <translation>Dosya Sistemi</translation>
    </message>
</context>
<context>
    <name>LoginRemoteFilesystem</name>
    <message>
        <location filename="login-remote-filesystem.ui" line="41"/>
        <source>Connect to Sever</source>
        <translation type="unfinished">Sunucuya bağlan</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="89"/>
        <source>server information</source>
        <translation type="unfinished">Sunucu bilgisi</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="111"/>
        <source>user information</source>
        <translation type="unfinished">Kullanıcı bilgisi</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="141"/>
        <source>tag</source>
        <translation type="unfinished">Etiket</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="196"/>
        <source>user</source>
        <translation type="unfinished">Kullanıcı</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="252"/>
        <source>password</source>
        <translation type="unfinished">Parola</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="308"/>
        <source>protocol</source>
        <translation type="unfinished">Protokol</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="351"/>
        <source>server</source>
        <translation type="unfinished">Sunucu</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="382"/>
        <source>directory</source>
        <translation type="unfinished">Dizin</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="411"/>
        <source>SAMBA</source>
        <translation type="unfinished">SAMBA</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="416"/>
        <source>FTP</source>
        <translation type="unfinished">FTP</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="445"/>
        <source>/</source>
        <translation type="unfinished">/</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="476"/>
        <source>port</source>
        <translation type="unfinished">Port</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="508"/>
        <source>20</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="513"/>
        <source>21</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="518"/>
        <source>137</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="523"/>
        <source>138</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="528"/>
        <source>139</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="533"/>
        <source>445</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="592"/>
        <source>ok</source>
        <translation type="unfinished">Tamam</translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="623"/>
        <source>cancel</source>
        <translation type="unfinished">İptal</translation>
    </message>
</context>
<context>
    <name>Peony::ComputerViewContainer</name>
    <message>
        <location filename="computer-view-container.cpp" line="94"/>
        <source>Connect a server</source>
        <translation>Servere bağlan</translation>
    </message>
    <message>
        <source>sftp://, etc...</source>
        <translation type="vanished">sftp://, gibi...</translation>
    </message>
    <message>
        <location filename="computer-view-container.cpp" line="117"/>
        <source>Unmount</source>
        <translation>Bağlantıyı kes</translation>
    </message>
    <message>
        <location filename="computer-view-container.cpp" line="123"/>
        <source>Eject</source>
        <translation type="unfinished">Çıkar</translation>
    </message>
    <message>
        <location filename="computer-view-container.cpp" line="133"/>
        <location filename="computer-view-container.cpp" line="148"/>
        <source>Property</source>
        <translation>Özellik</translation>
    </message>
    <message>
        <location filename="computer-view-container.cpp" line="135"/>
        <source>You have to mount this volume first</source>
        <translation>Önce bu bölümü bağlamalısınız</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="peony-computer-view-plugin.h" line="42"/>
        <source>Computer View</source>
        <translation>Bilgisayar Görünümü</translation>
    </message>
    <message>
        <location filename="peony-computer-view-plugin.h" line="43"/>
        <source>Show drives, network and personal directories.</source>
        <translation>Sürücüleri, ağı ve kişisel dizinleri göster.</translation>
    </message>
    <message>
        <location filename="computer-view/computer-volume-item.cpp" line="338"/>
        <source>One or more programs prevented the unmount operation.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="computer-view/computer-volume-item.cpp" line="340"/>
        <source>Unmount failed</source>
        <translation type="unfinished">Bağlantıyı kesme başarısız</translation>
    </message>
    <message>
        <location filename="computer-view/computer-volume-item.cpp" line="341"/>
        <source>Error: %1
Do you want to unmount forcely?</source>
        <translation type="unfinished">Hata: %1
        Zorla ayrılmak ister misin?</translation>
    </message>
    <message>
        <location filename="computer-view/computer-volume-item.cpp" line="360"/>
        <source>Eject failed</source>
        <translation type="unfinished">Çıkarma başarısız</translation>
    </message>
    <message>
        <location filename="computer-view/computer-volume-item.cpp" line="361"/>
        <source>Cancel</source>
        <translation type="unfinished">İptal</translation>
    </message>
    <message>
        <location filename="computer-view/computer-volume-item.cpp" line="362"/>
        <source>Eject Anyway</source>
        <translation type="unfinished">Yine de Çıkar</translation>
    </message>
</context>
</TS>
